@@ -5,7 +5,6 @@
 
 ;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1993/11/20
-;; Version: $Revision: 7.11 $
 ;; Keywords: news, MIME, multimedia, multilingual, encoded-word
 
 ;; This file is not part of tm (Tools for MIME).
@@ -33,10 +32,10 @@
 (require 'gnus)
 (require 'tm-gd3)
 
-(autoload 'mime/decode-message-header
-  "tm-ew-d" "Decode MIME encoded-words in message header." t)
-(autoload 'mime-eword/decode-string
-  "tm-ew-d" "Decode MIME encoded-words in string." t)
+(autoload 'mime-decode-header-in-buffer
+  "eword-decode" "Decode MIME encoded-words in message header." t)
+(autoload 'eword-decode-string
+  "eword-decode" "Decode MIME encoded-words in string." t)
 
 (fset 'gnus-summary-select-article 'gnus-Subject-select-article)
 
@@ -94,7 +93,7 @@ If you don't like it, define your own gnus-article-set-mode-line."
   (let ((maxlen 15)			;Maximum subject length
 	(subject
 	 (if gnus-current-headers
-	     (mime-eword/decode-string
+	     (eword-decode-string
 	      (nntp-header-subject gnus-current-headers))
 	   "")
 	 ))
@@ -254,7 +253,7 @@ With arg, turn MIME encoded-word processing on iff arg is positive."
 	   (cond ((boundp 'all-headers) (not all-headers))
 		 (t                     t))
 	   )
-      (mime/decode-message-header)
+      (mime-decode-header-in-buffer)
     )
   (run-hooks 'tm-gnus/article-prepare-hook)
   )
