@@ -6,7 +6,7 @@
 ;;         OKABE Yasuo <okabe@kudpc.kyoto-u.ac.jp>
 ;; Maintainer: MORIOKA Tomohiko <morioka@jaist.ac.jp>
 ;; Created: 1996/2/29 (separated from tm-mh-e.el)
-;; Version: $Id: tmh-comp.el,v 7.11 1997/01/31 11:55:05 morioka Exp $
+;; Version: $Id: tmh-comp.el,v 7.14 1997/03/18 15:05:22 morioka Exp $
 ;; Keywords: mail, MH, MIME, multimedia, encoded-word, multilingual
 
 ;; This file is part of tm (Tools for MIME).
@@ -125,7 +125,7 @@ system MH lib directory.")
 		      nil)))
     (setq number
 	  (if (numberp number)
-	      (number-to-string number)
+	      (int-to-string number)
 	    (tm-mh-e/prompt-for-message "Message number: " folder)
 	    ))
     (tm-mh-e::make-message folder number)
@@ -225,12 +225,9 @@ See also documentation for `\\[mh-send]' function."
 		     (if (get-buffer name)
 			 (throw 'tag (pop-to-buffer name))
 		       )
-		     (let ((file-coding-system-for-read *noconv*)
-			   (filename
-			    (mh-msg-filename msg mh-draft-folder)
-			    ))
+		     (let ((filename (mh-msg-filename msg mh-draft-folder)))
 		       (set-buffer (get-buffer-create name))
-		       (insert-file-contents filename)
+		       (as-binary-input-file (insert-file-contents filename))
 		       (setq buffer-file-name filename)
 		       (setq code-conversion t)
 		       )
@@ -241,9 +238,9 @@ See also documentation for `\\[mh-send]' function."
 		     name))
 		  (t
 		   (prog1
-		       (let ((file-coding-system-for-read *noconv*))
-			 (mh-read-draft "clean-up" (mh-msg-filename msg) nil)
-			 )
+		       (as-binary-input-file
+			(mh-read-draft "clean-up" (mh-msg-filename msg) nil)
+			)
 		     (setq code-conversion t)
 		     ))))
 	   )
@@ -395,9 +392,9 @@ then prompt for the message sequence. See also documentation for
       (forward-line 1)
       (save-restriction
 	(narrow-to-region (point) (point-max))
-	(setq orig-from (mime-eword/decode-string
+	(setq orig-from (eword-decode-string
 			 (mh-get-header-field "From:")))
-	(setq orig-subject (mime-eword/decode-string
+	(setq orig-subject (eword-decode-string
 			    (mh-get-header-field "Subject:")))
 	)
       (let ((forw-subject
@@ -518,6 +515,31 @@ to select message yanking function."
  'mh-insert-letter 'tm-mh-e/insert-letter mh-letter-mode-map)
 
 
+;;; @ for mu-cite
+;;;
+
+(call-after-loaded
+ 'mu-cite
+ (function
+  (lambda ()
+    (set-alist 'mu-cite/get-field-value-method-alist
+	       'mh-letter-mode
+	       (function
+		(lambda (name)
+		  (if (and (stringp mh-sent-from-folder)
+			   (numberp mh-sent-from-msg))
+		      (save-excursion
+			(set-buffer mh-sent-from-folder)
+			(set-buffer mh-show-buffer)
+			(and (boundp 'mime::preview/article-buffer)
+			     (bufferp mime::preview/article-buffer)
+			     (set-buffer mime::preview/article-buffer))
+			(std11-field-body name)
+			))
+		  )))
+    )))
+
+		   
 ;;; @ end
 ;;;
 
