@@ -32,7 +32,7 @@
 (require 'tl-misc)
 (require 'std11)
 (require 'mel)
-(require 'tm-ew-d)
+(require 'eword-decode)
 (require 'tm-def)
 (require 'tm-parse)
 (require 'tm-text)
@@ -314,7 +314,7 @@ Each elements are regexp of field-name. [tm-view.el]")
 
 (defun mime-viewer/default-content-header-filter ()
   (mime-preview/cut-header)
-  (mime/decode-message-header)
+  (mime-decode-header-in-buffer)
   )
 
 (defvar mime-viewer/content-header-filter-alist nil)
@@ -503,7 +503,7 @@ The compressed face will be piped to this command.")
     (save-restriction
       (narrow-to-region beg end)
       (setq subj
-	    (mime-eword/decode-string
+	    (eword-decode-string
 	     (mime-article/get-subject params encoding)))
       )
     (set-buffer obuf)
@@ -1007,7 +1007,7 @@ button-2	Move to point under the mouse cursor
 		      ))
 		(setq rest (cdr rest))
 		))
-	    (mime/decode-message-header)
+	    (mime-decode-header-in-buffer)
 	    )
 	  (let ((f (cdr (assq mode mime-viewer/following-method-alist))))
 	    (if (functionp f)
